<?php

namespace Btravel\Organizer\Policies;

use Litepie\User\Contracts\UserPolicy;
use Btravel\Organizer\Models\Organizer;

class OrganizerPolicy
{

    /**
     * Determine if the given user can view the organizer.
     *
     * @param UserPolicy $user
     * @param Organizer $organizer
     *
     * @return bool
     */
    public function view(UserPolicy $user, Organizer $organizer)
    {
        if ($user->canDo('organizer.organizer.view') && $user->isAdmin()) {
            return true;
        }

        return $organizer->user_id == user_id() && $organizer->user_type == user_type();
    }

    /**
     * Determine if the given user can create a organizer.
     *
     * @param UserPolicy $user
     * @param Organizer $organizer
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('organizer.organizer.create');
    }

    /**
     * Determine if the given user can update the given organizer.
     *
     * @param UserPolicy $user
     * @param Organizer $organizer
     *
     * @return bool
     */
    public function update(UserPolicy $user, Organizer $organizer)
    {
        if ($user->canDo('organizer.organizer.edit') && $user->isAdmin()) {
            return true;
        }

        return $organizer->user_id == user_id() && $organizer->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given organizer.
     *
     * @param UserPolicy $user
     * @param Organizer $organizer
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Organizer $organizer)
    {
        return $organizer->user_id == user_id() && $organizer->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given organizer.
     *
     * @param UserPolicy $user
     * @param Organizer $organizer
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Organizer $organizer)
    {
        if ($user->canDo('organizer.organizer.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given organizer.
     *
     * @param UserPolicy $user
     * @param Organizer $organizer
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Organizer $organizer)
    {
        if ($user->canDo('organizer.organizer.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
